==> haskell-interpolatedstring-perl6-1.0.2-391-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-interpolatedstring-perl6.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 interpolatedstring-perl6
version:              1.0.2
visibility:           public
id:                   interpolatedstring-perl6-1.0.2-6Sdf8D6t8lvi1nSYQ0Hrb
key:                  interpolatedstring-perl6-1.0.2-6Sdf8D6t8lvi1nSYQ0Hrb
license:              LicenseRef-PublicDomain
copyright:            Audrey Tang
maintainer:           Audrey Tang <audreyt@audreyt.org>
author:               Audrey Tang
stability:            stable
synopsis:             QuasiQuoter for Perl6-style multi-line interpolated strings
description:
    QuasiQuoter for Perl6-style multi-line interpolated strings with \"q\", \"qq\" and \"qc\" support.

category:             Data
abi:                  0a12e512e71bf84388c309e9ba6fc285
exposed:              True
exposed-modules:      Text.InterpolatedString.Perl6
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/interpolatedstring-perl6-1.0.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/interpolatedstring-perl6-1.0.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/interpolatedstring-perl6-1.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-interpolatedstring-perl6
hs-libraries:         HSinterpolatedstring-perl6-1.0.2-6Sdf8D6t8lvi1nSYQ0Hrb
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    haskell-src-meta-0.8.15-5WFitTxLlY3F4m3fvGyHMw
    template-haskell-2.19.0.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-interpolatedstring-perl6/html/interpolatedstring-perl6.haddock

haddock-html:         /usr/share/doc/haskell-interpolatedstring-perl6/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-interpolatedstring-perl6-1.0.2-392-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-interpolatedstring-perl6.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 interpolatedstring-perl6
version:              1.0.2
visibility:           public
id:                   interpolatedstring-perl6-1.0.2-GrLOA0dCSro7xZisBw2PgS
key:                  interpolatedstring-perl6-1.0.2-GrLOA0dCSro7xZisBw2PgS
license:              LicenseRef-PublicDomain
copyright:            Audrey Tang
maintainer:           Audrey Tang <audreyt@audreyt.org>
author:               Audrey Tang
stability:            stable
synopsis:             QuasiQuoter for Perl6-style multi-line interpolated strings
description:
    QuasiQuoter for Perl6-style multi-line interpolated strings with \"q\", \"qq\" and \"qc\" support.

category:             Data
abi:                  705945235da71ba4b4bceeaa2fc4f594
exposed:              True
exposed-modules:      Text.InterpolatedString.Perl6
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/interpolatedstring-perl6-1.0.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/interpolatedstring-perl6-1.0.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/interpolatedstring-perl6-1.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-interpolatedstring-perl6
hs-libraries:         HSinterpolatedstring-perl6-1.0.2-GrLOA0dCSro7xZisBw2PgS
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    haskell-src-meta-0.8.15-8cHsnnGBHc4DK9KGAuuIfM
    template-haskell-2.19.0.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-interpolatedstring-perl6/html/interpolatedstring-perl6.haddock

haddock-html:         /usr/share/doc/haskell-interpolatedstring-perl6/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
